/*
  Copyright (C) 2013 Jolla Ltd.
  Contact: Thomas Perl <thomas.perl@jollamobile.com>
  All rights reserved.

  You may use this file under the terms of BSD license as follows:

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of the Jolla Ltd nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR
  ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

import QtQuick 2.0
import Sailfish.Silica 1.0


Page {
    id: page

    property string pagename: "first"
    property var active: null
    property string activename: GameEngine.getActiveShip();
    property int player: GameEngine.getIActivePlayer();
    property int weapon: GameEngine.getActiveWeapon();
    property int textsize: 25
    property int boxsize: 60
    property var shiplist: ["sub","ship","cruiser"]

    // To enable PullDownMenu, place our content in a SilicaFlickable
    SilicaFlickable {
        anchors.fill: parent

        // PullDownMenu and PushUpMenu must be declared in SilicaFlickable, SilicaListView or SilicaGridView
        PullDownMenu {
            MenuItem {
                text: "Player" + GameEngine.getIActivePlayer() + (GameEngine.getGameState() === 3 ? ", stop shooting" :", end turn")
                onClicked: {
                    /*for (var i = 0; i < elements.count ; i++) {
                        var xp = 30 + 60 * (i % 9)
                        var yp = 30 + Math.floor( i / 9) * 60

                        maingrid.childAt(xp,yp).color = "transparent"
                        maingrid.childAt(xp,yp).radius = 0
                    }*/
                    //labeltext.text = "Player" + GameEngine.getIActivePlayer + "Placing turn"
                    if(GameEngine.getGameState() === 2) GameEngine.gameStateProgress()
                    else if(GameEngine.getGameState() === 3) GameEngine.gameStatePassTurn()
                    pageStack.clear();
                    pageStack.push(Qt.resolvedUrl("PlayerTurn.qml"))

                }
            }
        }

        // Tell SilicaFlickable the height of its content.
        contentHeight: gridcolumn.height

        // Place our content in a Column.  The PageHeader is always placed at the top
        // of the page, followed by our content.
        Column {
            id: gridcolumn
            Grid {
                id: maingrid
                columns: GameEngine.gameAreaX()
                rows: GameEngine.gameAreaY()
                spacing: 0
                Repeater {
                    id: elements
                    model: GameEngine.gameAreaX()*GameEngine.gameAreaY()
                    delegate: Placeblock {
                    }
                }
            }
            Item {
                Repeater {
                    id: ships
                    model: page.shiplist
                    delegate: Ship {
                        name: page.shiplist[index]
                    }
                }
            }

        }

        Label {
            id: mainlabel
            x: 25
            y: 25
            Text {
                id: labeltext
                text: "Select a ship"
                color: "white"
                font.pixelSize: textsize
            }
        }
        Label {
            id: infolabel
            x: 25
            y: 50
            Text {
                id: infotext
                text: "Player" + GameEngine.getIActivePlayer() + " at game state: " + GameEngine.getGameStateString(GameEngine.getGameState())
                color: "white"
                font.pixelSize: textsize
            }
        }
        Row {
            id: iconButtons
            spacing: 5
            x: page.active.x + boxsize*3 > GameEngine.gameAreaX()*boxsize ? page.active.x - boxsize : page.active.x + 5
            y: page.active.y + 5
            width: boxsize*4
            height: boxsize
            enabled: page.activename.length > 0 && GameEngine.getGameState() === 3 ? true : false
            visible: page.activename.length > 0 && GameEngine.getGameState() === 3 ? true : false
            //anchors.horizontalCenter: page.active
            IconButton {
                id: w1
                icon.source: "../pics/w1.png"
                width: boxsize-10
                height: boxsize-10
                onClicked: {
                    page.weapon = 1
                    GameEngine.setActiveWeapon(1)
                    labeltext.text = activename  + " A:" +  GameEngine.getShipArmor(activename) + " (" + GameEngine.getShipX(activename) + "," + GameEngine.getShipY(activename) + ") Selected: " + (weapon === 1 ? GameEngine.getShipWeapon1(activename) : weapon === 2 ? GameEngine.getShipWeapon2(activename) : "none selected")
                }
                enabled: page.weapon !== 1
            }
            IconButton {
                id: w2
                icon.source: "../pics/w2.png"
                width: boxsize-10
                height: boxsize-10
                onClicked: {
                    page.weapon = 2
                    GameEngine.setActiveWeapon(2)
                    labeltext.text = activename  + " A:" +  GameEngine.getShipArmor(activename) + " (" + GameEngine.getShipX(activename) + "," + GameEngine.getShipY(parent.name) + ") Selected: " + (weapon === 1 ? GameEngine.getShipWeapon1(activename) : weapon === 2 ? GameEngine.getShipWeapon2(activename) : "none selected")
                }

                enabled: page.weapon !== 2
            }
            IconButton {
                id: shoot
                icon.source: "../pics/s.png"
                width: boxsize-10
                height: boxsize-10
                onClicked: if(GameEngine.getGameState() === 3) pageStack.push(Qt.resolvedUrl("SecondPage.qml"))
                enabled: page.weapon > 0
            }
       }
        /*Row {
            id: rotateicons
            spacing: 20
            x: page.active.x + 10
            y: page.active.y + boxsize/4
            width: boxsize*4
            height: boxsize
            enabled: page.activename.length > 0 && GameEngine.getGameState() === 2 ? true : false
            visible: page.activename.length > 0 && GameEngine.getGameState() === 2 ? true : false
            IconButton {
                id: rotatel
                icon.source: "image://theme/icon-l-left"
                width: boxsize/2
                height: boxsize/2
                onClicked: {
                    if(active.rotation > 0) active.rotation -= 90
                    else active.rotation = 270
                }
            }
            IconButton {
                id: rotater
                icon.source: "image://theme/icon-r-left"
                width: boxsize/2
                height: boxsize/2
                onClicked: {
                    if(active.rotation === 270) active.rotation = 0;
                    else active.rotation += 90
                }
            }
        }*/
    }
}



